@@ -699,3 +699,47 @@ class Country(Base):
 
     def __str__(self):
         return self.name_ru
+
+
+class EduStatus(Base):
+    """
+    Статус студента
+    """
+    __tablename__ = 'univer_student_edu_statuses'
+
+    # Идентификатор
+    id = Column('student_edu_status_id', Integer, primary_key=True)
+
+    # Наименование
+    name_ru = Column('student_edu_status_name_ru', String(100))
+    name_kz = Column('student_edu_status_name_kz', String(100))
+    name_en = Column('student_edu_status_name_en', String(100))
+
+    # Статус
+    # Возможные значения:
+    # - 1 (Активный)
+    # - 2 (Архивный)
+    status = Column(Integer)
+
+    @validates('status')
+    def validate_status(self, key, value):
+        assert value in [1, 2]
+        return value
+
+    # Статус для студента
+    # Возможные значения:
+    # - 1 (Активный)
+    # - 2 (Архивный)
+    # - 10 (Абитуриент)
+    status_for_student = Column(Integer)
+
+    @validates('status_for_student')
+    def validate_status_for_student(self, key, value):
+        assert value in [1, 2, 10]
+        return value
+
+    def __repr__(self):
+        return f'<EduStatus {self} (id={self.id} status={self.status})>'
+
+    def __str__(self):
+        return f'{self.name_ru}'
