@@ -1,5 +1,5 @@
 from sqlalchemy import Column, Integer, String, Float, Boolean, ForeignKey, Date, DateTime
-from sqlalchemy.orm import relationship
+from sqlalchemy.orm import relationship, validates
 
 from univer_db.orm import get_base
 
@@ -99,28 +99,54 @@ class Order(Base):
 
 class OrderType(Base):
     """
-    Модель "Типы приказов"
-    Статус: Выполняется
+    Типы приказов
     """
-
     __tablename__ = 'univer_order_type'
 
     # Идентификатор
     id = Column('order_type_id', Integer, primary_key=True)
 
     # Статус
+    # Возможные значения:
+    # - 1 (Активный)
+    # - 2 (Архивный)
     status = Column(Integer)
 
+    @validates('status')
+    def validate_status(self, key, value):
+        """
+        Значением status могут быть следующие значения:
+        - 1 (Активный)
+        - 2 (Архивный)
+        """
+        assert value in [1, 2]
+        return value
+
     # Наименование
     name_ru = Column('order_type_name_ru', String(300))
     name_kz = Column('order_type_name_kz', String(300))
     name_en = Column('order_type_name_en', String(300))
 
+    # Неизвестное поле
+    template = Column('order_type_template', String(150))
+
+    # Неизвестное поле
+    need_signed = Column('order_type_need_signed', Integer)
+
+    # Неизвестное поле
+    order_folder = Column('order_folder', Column(30))
+
+    # Неизвестное поле
+    is_action = Column('order_type_is_action', Integer)
+
+    # Неизвестное поле
+    order_class_id = Column(Integer)
+
     def __repr__(self):
-        return '<OrderType {} (id={} status={})>'.format(self, self.id, self.status)
+        return f'<OrderType {self} (id={self.id} status={self.status})>'
 
     def __str__(self):
-        return self.name_ru
+        return f'{self.name_ru}'
 
 
 class OrderAction(Base):
@@ -184,3 +210,91 @@ class OrderStudentLink(Base):
 
     def __str__(self):
         return '{} ({})'.format(self.student, self.order)
+
+
+class OrderReasonLink(Base):
+    """
+    Основание для приказа
+    """
+    __tablename__ = 'univer_order_reason_link'
+
+    # Идентификатор
+    id = Column('order_reason_link_id', Integer, primary_key=True)
+
+    # Наименование
+    name_ru = Column('order_reason_link_text_ru', String)
+    name_kz = Column('order_reason_link_text_kz', String)
+    name_en = Column('order_reason_link_text_en', String)
+
+    # Статус
+    # Возможные значения:
+    # - 1 (Активный)
+    # - 2 (Архивный)
+    status = Column(Integer)
+
+    @validates('status')
+    def validate_status(self, key, value):
+        """
+        Значением status могут быть следующие значения:
+        - 1 (Активный)
+        - 2 (Архивный)
+        """
+        assert value in [1, 2]
+        return value
+
+    def __repr__(self):
+        return f'<OrderReasonLink {self} (id={self.id} status={self.status})>'
+
+    def __str__(self):
+        return f'{self.name_ru}'
+
+
+class OrderReason(Base):
+    """
+    Причина для приказа
+    """
+    __tablename__ = 'univer_order_reasons'
+
+    # Идентификатор
+    id = Column('order_reason_id', Integer, primary_key=True)
+
+    # Наименование
+    name_ru = Column('order_reason_name_ru', String(500))
+    name_kz = Column('order_reason_name_kz', String(500))
+    name_en = Column('order_reason_name_en', String(500))
+
+    # Статус студента
+    edu_status_id = Column('student_edu_status_id', ForeignKey(
+        'univer_student_edu_statuses.student_edu_status_id'))
+    edu_status = relationship('EduStatus')
+
+    # Статус
+    # Возможные значения:
+    # - 1 (Активный)
+    # - 2 (Архивный)
+    status = Column(Integer)
+
+    @validates('status')
+    def validate_status(self, key, value):
+        """
+        Значением status могут быть следующие значения:
+        - 1 (Активный)
+        - 2 (Архивный)
+        """
+        assert value in [1, 2]
+        return value
+
+    # Тип приказа
+    order_type_id = Column(ForeignKey('univer_order_type.order_type_id'))
+    order_type = relationship('OrderType')
+
+    # Основание для приказа (OrderReasonLink)
+    order_reason_link_id = Column(ForeignKey(
+        'univer_order_reason_link.order_reason_link_id'))
+    order_reason_link = relationship('OrderReasonLink')
+
+    def __repr__(self):
+        return f'<OrderReason {self} (id={self.id} status={self.status})>'
+
+    def __str__(self):
+        return f'{self.name_ru}'
